Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClément Foucault <foucault.clem@gmail.com>2018-07-18 01:12:21 +0300
committerClément Foucault <foucault.clem@gmail.com>2018-07-18 12:49:15 +0300
commit8cd7828792419fb4eac9a2a477968535b4c71535 (patch)
tree8fc733149fe07b7d9edd4b8b1e709519b4481887 /source/blender/gpu/intern/gpu_batch_private.h
parent247ad2034de2c33a6d9cb7d3b6f1ef7ffa5b859d (diff)
GWN: Port to GPU module: Replace GWN prefix by GPU
Diffstat (limited to 'source/blender/gpu/intern/gpu_batch_private.h')
-rw-r--r--source/blender/gpu/intern/gpu_batch_private.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/source/blender/gpu/intern/gpu_batch_private.h b/source/blender/gpu/intern/gpu_batch_private.h
index 1e72bae503f..0b25c0aef05 100644
--- a/source/blender/gpu/intern/gpu_batch_private.h
+++ b/source/blender/gpu/intern/gpu_batch_private.h
@@ -23,15 +23,15 @@
* ***** END GPL LICENSE BLOCK *****
*/
-/** \file blender/gpu/gwn_batch_private.h
+/** \file blender/gpu/intern/gpu_batch_private.h
* \ingroup gpu
*
* Gawain geometry batch
* Contains VAOs + VBOs + Shader representing a drawable entity.
*/
-#ifndef __GWN_BATCH_PRIVATE_H__
-#define __GWN_BATCH_PRIVATE_H__
+#ifndef __GPU_BATCH_PRIVATE_H__
+#define __GPU_BATCH_PRIVATE_H__
#ifdef __cplusplus
extern "C" {
@@ -41,13 +41,13 @@ extern "C" {
#include "GPU_context.h"
#include "GPU_shader_interface.h"
-void gwn_batch_remove_interface_ref(Gwn_Batch*, const Gwn_ShaderInterface*);
+void gpu_batch_remove_interface_ref(GPUBatch*, const GPUShaderInterface*);
-void gwn_context_add_batch(Gwn_Context*, Gwn_Batch*);
-void gwn_context_remove_batch(Gwn_Context*, Gwn_Batch*);
+void gpu_context_add_batch(GPUContext*, GPUBatch*);
+void gpu_context_remove_batch(GPUContext*, GPUBatch*);
#ifdef __cplusplus
}
#endif
-#endif /* __GWN_BATCH_PRIVATE_H__ */
+#endif /* __GPU_BATCH_PRIVATE_H__ */
@@ -23,15 +23,15 @@
* \ingroup gpu
*
- * Gawain geometry batch
+ * GPU geometry batch
* Contains VAOs + VBOs + Shader representing a drawable entity.
*/